# Ontolocy

An open source cyber security graph ontology.

Use Python and Neo4j to explore cyber security data as a graph.

Currently in alpha/proof-of-concept stage - the ontology is likely to change.
